@@ -156,7 +156,7 @@ def rtf_filter(text, metadata=None, styles=None, question=None):
     #sys.stderr.write(text + "\n")
     if 'fontsize' in metadata:
         text = re.sub(r'{\\pard', r'\\fs' + str(convert_length(metadata['fontsize'], 'hp')) + r' {\\pard', text, count=1)
-        after_space_multiplier = str(convert_length(metadata['fontsize'], 'twips'))
+        after_space_multiplier = convert_length(metadata['fontsize'], 'twips')
     else:
         after_space_multiplier = 240
     if 'IndentationAmount' in metadata:
@@ -1261,6 +1261,7 @@ def markdown_to_html(a, trim=False, pclass=None, status=None, question=None, use
             # Try again because sometimes it fails randomly and maybe trying again will work.
             result = docassemble.base.functions.this_thread.markdown.reset().convert(a)
     result = re.sub(r'<table>', r'<table class="table table-striped">', result)
+    result = re.sub(r'<(t[dh]) align="(right|left|center)">', r'<\1 class="text-\2">', result)
     result = re.sub(r'<blockquote>', r'<blockquote class="blockquote">', result)
     #result = re.sub(r'<table>', r'<table class="datable">', result)
     result = re.sub(r'<a href="(.*?)"', lambda x: link_rewriter(x, status), result)
